[Libreoffice-commits] core.git: Branch 'distro/collabora/cp-6.2' - configure.ac .gitignore instsetoo_native/util setup_native/source solenv/bin

Andras Timar (via logerrit) logerrit at kemper.freedesktop.org
Fri Apr 24 17:46:20 UTC 2020


 .gitignore                                           |    1 +
 configure.ac                                         |    3 +++
 instsetoo_native/util/openoffice.lst.in              |    2 +-
 setup_native/source/packinfo/finals_instsetoo.txt.in |    1 +
 solenv/bin/modules/installer/globals.pm              |    2 +-
 solenv/bin/modules/installer/windows/admin.pm        |    3 ++-
 solenv/bin/modules/installer/windows/msp.pm          |    2 +-
 7 files changed, 10 insertions(+), 4 deletions(-)

New commits:
commit 70e34e275af01341c049ac3b7fc333621adcaf82
Author:     Andras Timar <andras.timar at collabora.com>
AuthorDate: Mon Oct 10 13:56:31 2016 -0700
Commit:     Andras Timar <andras.timar at collabora.com>
CommitDate: Fri Apr 24 19:45:49 2020 +0200

    [cp] Enable MSP patching
    
    (cherry picked from commit ae8938f8848bcce96e21ee207c0226ff0a3cb4a2)
    
    Change-Id: I1de9776e161161daf7349be304e05d5bb959f891
    Reviewed-on: https://gerrit.libreoffice.org/c/core/+/92847
    Tested-by: Jenkins CollaboraOffice <jenkinscollaboraoffice at gmail.com>
    Reviewed-by: Andras Timar <andras.timar at collabora.com>

diff --git a/.gitignore b/.gitignore
index 45d7859318e5..46ff6df9b846 100644
--- a/.gitignore
+++ b/.gitignore
@@ -64,6 +64,7 @@
 /README
 /AUTHORS
 /MAINTAINERS
+/setup_native/source/packinfo/finals_instsetoo.txt
 
 # make id
 /ID
diff --git a/configure.ac b/configure.ac
index 658a72b7e783..76cc8f5f3ca8 100644
--- a/configure.ac
+++ b/configure.ac
@@ -3183,6 +3183,7 @@ if test "$_os" = "WINNT"; then
         BITNESS_OVERRIDE=64
     fi
 fi
+AC_SUBST(WINDOWS_SDK_ARCH)
 if test "$_os" = "iOS"; then
     cross_compiling="yes"
 fi
@@ -4568,6 +4569,7 @@ if test "$cross_compiling" = "yes"; then
         bin/odfvalidator.sh.in \
         bin/officeotron.sh.in \
         instsetoo_native/util/openoffice.lst.in \
+        setup_native/source/packinfo/finals_instsetoo.txt.in \
         config_host/*.in \
         sysui/desktop/macosx/Info.plist.in) \
     | (cd CONF-FOR-BUILD && tar xf -)
@@ -12966,6 +12968,7 @@ AC_CONFIG_FILES([config_host.mk
                  bin/odfvalidator.sh
                  bin/officeotron.sh
                  instsetoo_native/util/openoffice.lst
+                 setup_native/source/packinfo/finals_instsetoo.txt
                  sysui/desktop/macosx/Info.plist])
 AC_CONFIG_HEADERS([config_host/config_buildid.h])
 AC_CONFIG_HEADERS([config_host/config_clang.h])
diff --git a/instsetoo_native/util/openoffice.lst.in b/instsetoo_native/util/openoffice.lst.in
index 2616587940c9..485c328dbaa6 100644
--- a/instsetoo_native/util/openoffice.lst.in
+++ b/instsetoo_native/util/openoffice.lst.in
@@ -27,7 +27,7 @@ Globals
             REGISTRYLAYERNAME Layers
             SERVICEPACK 1
             UPDATE_DATABASE 1
-            CREATE_MSP_INSTALLSET 0
+            CREATE_MSP_INSTALLSET 1
             UPDATE_DATABASE_LISTNAME finals_instsetoo.txt
             PACKAGEMAP package_names.txt,package_names_ext.txt
             WINDOWSPATCHLEVEL @LIBO_VERSION_PATCH@
diff --git a/setup_native/source/packinfo/finals_instsetoo.txt b/setup_native/source/packinfo/finals_instsetoo.txt.in
similarity index 82%
rename from setup_native/source/packinfo/finals_instsetoo.txt
rename to setup_native/source/packinfo/finals_instsetoo.txt.in
index d5a68d369f7b..52abc3729fe3 100644
--- a/setup_native/source/packinfo/finals_instsetoo.txt
+++ b/setup_native/source/packinfo/finals_instsetoo.txt.in
@@ -30,3 +30,4 @@
 # OpenOffice	pro		de			\\<server>\<path>\msi\OOO300_m6_native_packed-1_de.9352\openofficeorg30.msi
 # OpenOfficeLanguagePack	pro	es	\\<server>\<path>\msi\OOO300_m6_native_packed-1_es.9352\openofficeorg30.msi
 # URE			pro		en-US		\\<server>\<path>\msi\OOO300_m6_native_packed-1_en-US.9352\ure14.msi
+CollaboraOffice		pro		en-US,ar,as,ast,bg,bn-IN,br,ca,ca-valencia,cy,cs,da,de,el,en-GB,es,et,eu,fi,fr,ga,gd,gl,gu,he,hi,hr,hu,id,is,it,ja,km,kn,ko,lt,lv,ml,mr,nb,nl,nn,oc,or,pa-IN,pl,pt,pt-BR,ro,ru,sk,sl,sr,sr-Latn,sv,ta,te,tr,uk,vi,zh-CN,zh-TW		c:\lo\src\cp-6.2-9- at WINDOWS_SDK_ARCH@\Collabora_Office_6.2-9_Win_ at WINDOWS_SDK_ARCH@.msi
diff --git a/solenv/bin/modules/installer/globals.pm b/solenv/bin/modules/installer/globals.pm
index a7ec5e50b209..a5bd3b93d5df 100644
--- a/solenv/bin/modules/installer/globals.pm
+++ b/solenv/bin/modules/installer/globals.pm
@@ -220,7 +220,7 @@ BEGIN
     $fix_number_of_cab_files = 1;
     $cabfilecompressionlevel = 21; # Using LZX compression, possible values are: 15 | 16 | ... | 21 (best compression)
     $number_of_cabfiles = 1;    # only for $fix_number_of_cab_files = 1
-    $include_cab_in_msi = 1;
+    $include_cab_in_msi = 0;
     $msidatabasename = "";
     $prepare_winpatch = 0;
     $previous_idt_dir = "";
diff --git a/solenv/bin/modules/installer/windows/msp.pm b/solenv/bin/modules/installer/windows/msp.pm
index 1e76947df7b0..e76d5da7ab7f 100644
--- a/solenv/bin/modules/installer/windows/msp.pm
+++ b/solenv/bin/modules/installer/windows/msp.pm
@@ -288,7 +288,7 @@ sub set_mspfilename
 {
     my ($allvariables, $mspdir, $languagesarrayref) = @_;
 
-    my $databasename = $allvariables->{'PRODUCTNAME'} . "-" . $allvariables->{'PRODUCTVERSION'} . "-" . $allvariables->{'WINDOWSPATCHLEVEL'} . ".msp";
+    my $databasename = $allvariables->{'ONEWORDPRODUCTNAME'} . "-" . $allvariables->{'PRODUCTVERSION'} . "-" . $allvariables->{'WINDOWSPATCHLEVEL'} . ".msp";
 
     my $fullmspname = $mspdir . $installer::globals::separator . $databasename;
 


More information about the Libreoffice-commits mailing list
diff --git a/solenv/bin/modules/installer/windows/admin.pm b/solenv/bin/modules/installer/windows/admin.pm
index f822afe7eaec..3dfba9e7a8de 100644
--- a/solenv/bin/modules/installer/windows/admin.pm
+++ b/solenv/bin/modules/installer/windows/admin.pm
@@ -287,8 +287,9 @@ sub create_directory_structure
     {
         if ( ! exists($fullpathhash{$dir}) ) { $fullpathhash{$dir} = $targetdir; }
     }
     # FIXME why is this hack needed? ERROR: Did not find full directory path for dir: "ystemFolder_x86_VC.194841A2_D0F2_3B96_9F71_05BA91BEA0FA"
     $fullpathhash{"SystemFolder_x86_VC.194841A2_D0F2_3B96_9F71_05BA91BEA0FA"} = $targetdir . $installer::globals::separator . "System";
+    $fullpathhash{"SystemFolder_x86_VC.E281B893_10D7_34CE_BB0E_B69D88E154A5"} = $targetdir . $installer::globals::separator . "System";
     $fullpathhash{"System64Folder_amd64_VC.AF4EABEE_4589_3789_BA0A_C83A71662E1D"} = $targetdir . $installer::globals::separator . "System64";
 
     return \%fullpathhash;
@@ -287,8 +287,9 @@ sub create_directory_structure
         if ( ! exists($fullpathhash{$dir}) ) { $fullpathhash{$dir} = $targetdir; }
     }
-    # FIXME why is this hack needed? ERROR: Did not find full directory path for dir: "ystemFolder_x86_VC.194841A2_D0F2_3B96_9F71_05BA91BEA0FA"
+    # FIXME why is this hack needed? ERROR: Did not find full directory path for dir: "SystemFolder_x86_VC.194841A2_D0F2_3B96_9F71_05BA91BEA0FA"
     $fullpathhash{"SystemFolder_x86_VC.194841A2_D0F2_3B96_9F71_05BA91BEA0FA"} = $targetdir . $installer::globals::separator . "System";